@@ -29,11 +29,14 @@ index((scanl), 5, apply, apply).
 index((scanl), 6, apply, apply).
 index((scanl), 7, apply, apply).
 index((archive_open), 3, archive, archive).
+index((archive_open), 4, archive, archive).
+index((archive_create), 3, archive, archive).
 index((archive_close), 1, archive, archive).
 index((archive_property), 2, archive, archive).
 index((archive_next_header), 2, archive, archive).
 index((archive_open_entry), 2, archive, archive).
 index((archive_header_property), 2, archive, archive).
+index((archive_set_header_property), 2, archive, archive).
 index((archive_extract), 3, archive, archive).
 index((archive_entries), 2, archive, archive).
 index((archive_data_stream), 3, archive, archive).
@@ -64,6 +67,7 @@ index(('$argv'), 1, backward_compatibility, backcomp).
 index(('$set_prompt'), 1, backward_compatibility, backcomp).
 index(('$strip_module'), 3, backward_compatibility, backcomp).
 index(('$declare_module'), 3, backward_compatibility, backcomp).
+index(('$module'), 2, backward_compatibility, backcomp).
 index((at_initialization), 1, backward_compatibility, backcomp).
 index((displayq), 1, backward_compatibility, backcomp).
 index((displayq), 2, backward_compatibility, backcomp).
@@ -77,6 +81,7 @@ index((read_clause), 1, backward_compatibility, backcomp).
 index((read_clause), 2, backward_compatibility, backcomp).
 index((read_variables), 2, backward_compatibility, backcomp).
 index((read_variables), 3, backward_compatibility, backcomp).
+index((read_pending_input), 3, backward_compatibility, backcomp).
 index((feature), 2, backward_compatibility, backcomp).
 index((set_feature), 2, backward_compatibility, backcomp).
 index((substring), 4, backward_compatibility, backcomp).
@@ -109,12 +114,31 @@ index((merge_set), 3, backward_compatibility, backcomp).
 index((index), 1, backward_compatibility, backcomp).
 index((hash), 1, backward_compatibility, backcomp).
 index((set_base_module), 1, backward_compatibility, backcomp).
+index((eval_license), 0, backward_compatibility, backcomp).
 index((base32), 2, base32, base32).
 index((base32), 3, base32, base32).
 index((base64), 2, base64, base64).
 index((base64url), 2, base64, base64).
 index((base64), 3, base64, base64).
 index((base64url), 3, base64, base64).
+index((bdb_init), 1, bdb, bdb).
+index((bdb_init), 2, bdb, bdb).
+index((bdb_close_environment), 1, bdb, bdb).
+index((bdb_current_environment), 1, bdb, bdb).
+index((bdb_environment_property), 2, bdb, bdb).
+index((bdb_open), 4, bdb, bdb).
+index((bdb_close), 1, bdb, bdb).
+index((bdb_closeall), 0, bdb, bdb).
+index((bdb_current), 1, bdb, bdb).
+index((bdb_put), 3, bdb, bdb).
+index((bdb_del), 3, bdb, bdb).
+index((bdb_delall), 3, bdb, bdb).
+index((bdb_enum), 3, bdb, bdb).
+index((bdb_get), 3, bdb, bdb).
+index((bdb_getall), 3, bdb, bdb).
+index((bdb_transaction), 1, bdb, bdb).
+index((bdb_transaction), 2, bdb, bdb).
+index((bdb_version), 1, bdb, bdb).
 index((listen), 3, broadcast, broadcast).
 index((listen), 2, broadcast, broadcast).
 index((unlisten), 1, broadcast, broadcast).
@@ -123,6 +147,7 @@ index((unlisten), 3, broadcast, broadcast).
 index((listening), 3, broadcast, broadcast).
 index((broadcast), 1, broadcast, broadcast).
 index((broadcast_request), 1, broadcast, broadcast).
+index((xml_write_canonical), 3, c14n2, c14n2).
 index((cgi_get_form), 1, cgi, cgi).
 index((format_to_chars), 3, charsio, charsio).
 index((format_to_chars), 4, charsio, charsio).
@@ -139,6 +164,7 @@ index((with_output_to_chars), 2, charsio, charsio).
 index((with_output_to_chars), 3, charsio, charsio).
 index((with_output_to_chars), 4, charsio, charsio).
 index((check_installation), 0, check_installation, check_installation).
+index((check_installation), 1, check_installation, check_installation).
 index((check_old_last), 0, checklast, checklast).
 index((check), 0, check, check).
 index((list_undefined), 0, check, check).
@@ -169,6 +195,24 @@ index((with_output_to_codes), 2, codesio, codesio).
 index((with_output_to_codes), 3, codesio, codesio).
 index((with_output_to_codes), 4, codesio, codesio).
 index((coinductive), 1, coinduction, coinduction).
+index((crypto_data_hash), 3, crypto, crypto).
+index((crypto_file_hash), 3, crypto, crypto).
+index((crypto_context_new), 2, crypto, crypto).
+index((crypto_data_context), 3, crypto, crypto).
+index((crypto_context_hash), 2, crypto, crypto).
+index((crypto_open_hash_stream), 3, crypto, crypto).
+index((crypto_stream_hash), 2, crypto, crypto).
+index((ecdsa_sign), 4, crypto, crypto).
+index((ecdsa_verify), 4, crypto, crypto).
+index((evp_decrypt), 6, crypto, crypto).
+index((evp_encrypt), 6, crypto, crypto).
+index((hex_bytes), 2, crypto, crypto).
+index((rsa_private_decrypt), 4, crypto, crypto).
+index((rsa_private_encrypt), 4, crypto, crypto).
+index((rsa_public_decrypt), 4, crypto, crypto).
+index((rsa_public_encrypt), 4, crypto, crypto).
+index((rsa_sign), 4, crypto, crypto).
+index((rsa_verify), 4, crypto, crypto).
 index((crypt), 2, crypt, crypt).
 index((csv), 3, csv, csv).
 index((csv), 4, csv, csv).
@@ -219,6 +263,16 @@ index((assertion), 1, prolog_debug, debug).
 index((expects_dialect), 1, prolog_dialect, dialect).
 index((exists_source), 1, prolog_dialect, dialect).
 index((source_exports), 2, prolog_dialect, dialect).
+index((dicts_same_tag), 2, dicts, dicts).
+index((dict_keys), 2, dicts, dicts).
+index((dicts_same_keys), 2, dicts, dicts).
+index((dicts_to_same_keys), 3, dicts, dicts).
+index((dict_fill), 4, dicts, dicts).
+index((dict_no_fill), 3, dicts, dicts).
+index((dicts_join), 3, dicts, dicts).
+index((dicts_join), 4, dicts, dicts).
+index((dicts_slice), 3, dicts, dicts).
+index((dicts_to_compounds), 4, dicts, dicts).
 index((dif), 2, dif, dif).
 index((doc_save), 2, pldoc_files, doc_files).
 index((doc_pack), 1, pldoc_files, doc_files).
@@ -249,8 +303,10 @@ index((instantiation_error), 1, error, error).
 index((uninstantiation_error), 1, error, error).
 index((representation_error), 1, error, error).
 index((syntax_error), 1, error, error).
+index((resource_error), 1, error, error).
 index((must_be), 2, error, error).
 index((is_of_type), 2, error, error).
+index((current_type), 3, error, error).
 index((explain), 1, prolog_explain, explain).
 index((explain), 2, prolog_explain, explain).
 index((fast_read), 1, fastrw, fastrw).
@@ -289,6 +345,8 @@ index((git_shortlog), 3, git, git).
 index((git_log_data), 3, git, git).
 index((git_show), 4, git, git).
 index((git_commit_data), 3, git, git).
+index((open_hash_stream), 3, hash_stream, hash_stream).
+index((stream_hash), 2, hash_stream, hash_stream).
 index((add_to_heap), 4, heaps, heaps).
 index((delete_from_heap), 4, heaps, heaps).
 index((empty_heap), 1, heaps, heaps).
@@ -314,6 +372,18 @@ index((iso_639_2), 2, iso_639, iso_639).
 index((iso_639_3), 2, iso_639, iso_639).
 index((iso_639), 2, iso_639, iso_639).
 index((isub), 4, isub, isub).
+index((lazy_list), 2, lazy_lists, lazy_lists).
+index((lazy_list), 3, lazy_lists, lazy_lists).
+index((lazy_list_materialize), 1, lazy_lists, lazy_lists).
+index((lazy_list_length), 2, lazy_lists, lazy_lists).
+index((lazy_findall), 3, lazy_lists, lazy_lists).
+index((lazy_findall), 4, lazy_lists, lazy_lists).
+index((lazy_get_codes), 4, lazy_lists, lazy_lists).
+index((lazy_read_terms), 4, lazy_lists, lazy_lists).
+index((lazy_read_lines), 4, lazy_lists, lazy_lists).
+index((lazy_message_queue), 4, lazy_lists, lazy_lists).
+index((lazy_engine_next), 4, lazy_lists, lazy_lists).
+index((lazy_list_iterator), 4, lazy_lists, lazy_lists).
 index((listing), 0, prolog_listing, listing).
 index((listing), 1, prolog_listing, listing).
 index((portray_clause), 1, prolog_listing, listing).
@@ -352,7 +422,9 @@ index((union), 3, lists, lists).
 index((subset), 2, lists, lists).
 index((subtract), 3, lists, lists).
 index((main), 0, prolog_main, main).
+index((argv_options), 3, prolog_main, main).
 index((make), 0, make, make).
+index((md5_hash), 3, md5, md5).
 index((new_memory_file), 1, memory_file, memfile).
 index((free_memory_file), 1, memory_file, memfile).
 index((size_memory_file), 2, memory_file, memfile).
@@ -371,8 +443,6 @@ index((memory_file_to_string), 3, memory_file, memfile).
 index((memory_file_substring), 5, memory_file, memfile).
 index((memory_file_line_position), 4, memory_file, memfile).
 index((utf8_position_memory_file), 3, memory_file, memfile).
-index((mime_parse), 2, mime, mime).
-index((mime_default_charset), 2, mime, mime).
 index((in_temporary_module), 3, modules, modules).
 index((nb_rb_insert), 3, nb_rbtrees, nb_rbtrees).
 index((nb_rb_get_node), 3, nb_rbtrees, nb_rbtrees).
@@ -493,6 +563,7 @@ index((pengine_io_goal_expansion), 2, pengines_io, pengines_io).
 index((persistent), 1, persistency, persistency).
 index((current_persistent_predicate), 1, persistency, persistency).
 index((db_attach), 2, persistency, persistency).
+index((db_detach), 0, persistency, persistency).
 index((db_sync), 1, persistency, persistency).
 index((db_sync_all), 1, persistency, persistency).
 index((doc_collect), 1, pldoc, pldoc).
@@ -600,6 +671,7 @@ index((xref_exported), 2, prolog_xref, prolog_xref).
 index((xref_module), 2, prolog_xref, prolog_xref).
 index((xref_uses_file), 3, prolog_xref, prolog_xref).
 index((xref_op), 2, prolog_xref, prolog_xref).
+index((xref_prolog_flag), 4, prolog_xref, prolog_xref).
 index((xref_comment), 3, prolog_xref, prolog_xref).
 index((xref_comment), 4, prolog_xref, prolog_xref).
 index((xref_mode), 3, prolog_xref, prolog_xref).
@@ -623,11 +695,11 @@ index((protobuf_message), 2, protobufs, protobufs).
 index((protobuf_message), 3, protobufs, protobufs).
 index((phrase_from_file), 2, pure_input, pure_input).
 index((phrase_from_file), 3, pure_input, pure_input).
+index((phrase_from_stream), 2, pure_input, pure_input).
+index((stream_to_lazy_list), 2, pure_input, pure_input).
 index((syntax_error), 3, pure_input, pure_input).
 index((lazy_list_location), 3, pure_input, pure_input).
 index((lazy_list_character_count), 3, pure_input, pure_input).
-index((phrase_from_stream), 2, pure_input, pure_input).
-index((stream_to_lazy_list), 2, pure_input, pure_input).
 index((pwp_files), 2, pwp, pwp).
 index((pwp_stream), 3, pwp, pwp).
 index((pwp_xml), 3, pwp, pwp).
@@ -701,20 +773,17 @@ index((rb_lookup), 3, rbtrees, rbtrees).
 index((rb_update), 4, rbtrees, rbtrees).
 index((rb_update), 5, rbtrees, rbtrees).
 index((rb_apply), 4, rbtrees, rbtrees).
-index((rb_lookupall), 3, rbtrees, rbtrees).
 index((rb_insert), 4, rbtrees, rbtrees).
 index((rb_insert_new), 4, rbtrees, rbtrees).
 index((rb_delete), 3, rbtrees, rbtrees).
 index((rb_delete), 4, rbtrees, rbtrees).
 index((rb_visit), 2, rbtrees, rbtrees).
-index((rb_visit), 3, rbtrees, rbtrees).
 index((rb_keys), 2, rbtrees, rbtrees).
-index((rb_keys), 3, rbtrees, rbtrees).
 index((rb_map), 2, rbtrees, rbtrees).
 index((rb_map), 3, rbtrees, rbtrees).
 index((rb_partial_map), 4, rbtrees, rbtrees).
+index((rb_fold), 4, rbtrees, rbtrees).
 index((rb_clone), 3, rbtrees, rbtrees).
-index((rb_clone), 4, rbtrees, rbtrees).
 index((rb_min), 3, rbtrees, rbtrees).
 index((rb_max), 3, rbtrees, rbtrees).
 index((rb_del_min), 4, rbtrees, rbtrees).
@@ -744,6 +813,10 @@ index((rdf_start_file), 2, rdf_triple, rdf_triple).
 index((rdf_end_file), 1, rdf_triple, rdf_triple).
 index((anon_prefix), 1, rdf_triple, rdf_triple).
 index((rdf_write_xml), 2, rdf_write, rdf_write).
+index((rl_read_init_file), 1, readline, readline).
+index((rl_add_history), 1, readline, readline).
+index((rl_write_history), 1, readline, readline).
+index((rl_read_history), 1, readline, readline).
 index((readln), 1, readln, readln).
 index((readln), 2, readln, readln).
 index((readln), 5, readln, readln).
@@ -762,6 +835,7 @@ index((rewrite), 2, rewrite, rewrite).
 index((rew_term_expansion), 2, rewrite, rewrite).
 index((rew_goal_expansion), 2, rewrite, rewrite).
 index((rlimit), 3, clib_rlimit, rlimit).
+index((saml_authenticate), 4, saml, saml).
 index((safe_goal), 1, sandbox, sandbox).
 index((safe_call), 1, sandbox, sandbox).
 index((setting), 4, settings, settings).
@@ -804,6 +878,8 @@ index((xml_quote_attribute), 2, sgml, sgml).
 index((xml_quote_cdata), 2, sgml, sgml).
 index((xml_name), 1, sgml, sgml).
 index((xml_name), 2, sgml, sgml).
+index((xsd_number_string), 2, sgml, sgml).
+index((xsd_time_string), 3, sgml, sgml).
 index((xml_basechar), 1, sgml, sgml).
 index((xml_ideographic), 1, sgml, sgml).
 index((xml_combining_char), 1, sgml, sgml).
@@ -824,6 +900,7 @@ index((sha_hash_ctx), 4, crypto_hash, sha).
 index((hmac_sha), 4, crypto_hash, sha).
 index((file_sha1), 2, crypto_hash, sha).
 index((hash_atom), 2, crypto_hash, sha).
+index((shell), 0, shell, shell).
 index((ls), 0, shell, shell).
 index((ls), 1, shell, shell).
 index((cd), 0, shell, shell).
@@ -878,23 +955,13 @@ index((load_public_key), 2, ssl, ssl).
 index((load_crl), 2, ssl, ssl).
 index((system_root_certificates), 1, ssl, ssl).
 index((cert_accept_any), 5, ssl, ssl).
-index((rsa_private_decrypt), 3, ssl, ssl).
-index((rsa_private_encrypt), 3, ssl, ssl).
-index((rsa_public_decrypt), 3, ssl, ssl).
-index((rsa_public_encrypt), 3, ssl, ssl).
-index((rsa_private_decrypt), 4, ssl, ssl).
-index((rsa_private_encrypt), 4, ssl, ssl).
-index((rsa_public_decrypt), 4, ssl, ssl).
-index((rsa_public_encrypt), 4, ssl, ssl).
 index((ssl_context), 3, ssl, ssl).
-index((ssl_init), 3, ssl, ssl).
-index((ssl_accept), 3, ssl, ssl).
-index((ssl_open), 3, ssl, ssl).
-index((ssl_open), 4, ssl, ssl).
+index((ssl_add_certificate_key), 4, ssl, ssl).
+index((ssl_set_sni_hook), 3, ssl, ssl).
 index((ssl_negotiate), 5, ssl, ssl).
 index((ssl_peer_certificate), 2, ssl, ssl).
+index((ssl_peer_certificate_chain), 2, ssl, ssl).
 index((ssl_session), 2, ssl, ssl).
-index((ssl_exit), 1, ssl, ssl).
 index((statistics), 0, prolog_statistics, statistics).
 index((statistics), 1, prolog_statistics, statistics).
 index((thread_statistics), 2, prolog_statistics, statistics).
@@ -937,8 +1004,14 @@ index((sub_string), 3, table, table).
 index((table_version), 2, table, table).
 index((sort_table), 2, table_util, table_util).
 index((verify_table_order), 1, table_util, table_util).
+index((table), 1, tabling, tabling).
+index((current_table), 2, tabling, tabling).
+index((abolish_all_tables), 0, tabling, tabling).
+index((abolish_table_subgoals), 1, tabling, tabling).
+index((start_tabling), 2, tabling, tabling).
 index((term_hash), 2, terms, terms).
 index((term_hash), 4, terms, terms).
+index((term_size), 2, terms, terms).
 index((term_variables), 2, terms, terms).
 index((term_variables), 3, terms, terms).
 index((variant), 2, terms, terms).
@@ -948,8 +1021,6 @@ index((cyclic_term), 1, terms, terms).
 index((acyclic_term), 1, terms, terms).
 index((term_subsumer), 3, terms, terms).
 index((term_factorized), 3, terms, terms).
-index((term_to_json), 3, term_to_json, term_to_json).
-index((term_to_json), 2, term_to_json, term_to_json).
 index((show_coverage), 1, prolog_cover, test_cover).
 index((make_tests), 3, test_wizard, test_wizard).
 index((make_test), 3, test_wizard, test_wizard).
@@ -1005,7 +1076,7 @@ index((reachable), 3, ugraphs, ugraphs).
 index((top_sort), 2, ugraphs, ugraphs).
 index((top_sort), 3, ugraphs, ugraphs).
 index((transitive_closure), 2, ugraphs, ugraphs).
-index((transpose), 2, ugraphs, ugraphs).
+index((transpose_ugraph), 2, ugraphs, ugraphs).
 index((vertices), 2, ugraphs, ugraphs).
 index((vertices_edges_to_ugraph), 3, ugraphs, ugraphs).
 index((ugraph_union), 3, ugraphs, ugraphs).
@@ -1013,6 +1084,7 @@ index((getuid), 1, uid, uid).
 index((getgid), 1, uid, uid).
 index((geteuid), 1, uid, uid).
 index((getegid), 1, uid, uid).
+index((getgroups), 1, uid, uid).
 index((user_info), 2, uid, uid).
 index((group_info), 2, uid, uid).
 index((user_data), 3, uid, uid).
@@ -1071,6 +1143,7 @@ index((numbervars), 1, varnumbers, varnumbers).
 index((varnumbers), 2, varnumbers, varnumbers).
 index((max_var_number), 3, varnumbers, varnumbers).
 index((varnumbers), 3, varnumbers, varnumbers).
+index((varnumbers_names), 3, varnumbers, varnumbers).
 index((vm_list), 1, prolog_vm, vm).
 index((when), 2, when, when).
 index((init_win_menus), 0, win_menu, win_menu).
@@ -1080,6 +1153,9 @@ index((swritef), 2, writef, writef).
 index((swritef), 3, writef, writef).
 index((www_open_url), 1, www_browser, www_browser).
 index((expand_url_path), 2, www_browser, www_browser).
+index((xmld_signed_DOM), 3, xmldsig, xmldsig).
+index((xmld_verify_signature), 4, xmldsig, xmldsig).
+index((decrypt_xml), 4, xmlenc, xmlenc).
 index((xpath), 3, xpath, xpath).
 index((xpath_chk), 3, xpath, xpath).
 index((xsdp_type), 1, xsdp_type, xsdp_types).
@@ -1087,6 +1163,25 @@ index((xsdp_uri_type), 2, xsdp_type, xsdp_types).
 index((xsdp_numeric_uri), 2, xsdp_type, xsdp_types).
 index((xsdp_subtype_of), 2, xsdp_type, xsdp_types).
 index((xsdp_convert), 3, xsdp_type, xsdp_types).
+index((>>), 2, yall, yall).
+index((>>), 3, yall, yall).
+index((>>), 4, yall, yall).
+index((>>), 5, yall, yall).
+index((>>), 6, yall, yall).
+index((>>), 7, yall, yall).
+index((>>), 8, yall, yall).
+index((>>), 9, yall, yall).
+index((/), 2, yall, yall).
+index((/), 3, yall, yall).
+index((/), 4, yall, yall).
+index((/), 5, yall, yall).
+index((/), 6, yall, yall).
+index((/), 7, yall, yall).
+index((/), 8, yall, yall).
+index((/), 9, yall, yall).
+index((lambda_calls), 2, yall, yall).
+index((lambda_calls), 3, yall, yall).
+index((is_lambda), 1, yall, yall).
 index((zopen), 3, zlib, zlib).
 index((gzopen), 3, zlib, zlib).
 index((gzopen), 4, zlib, zlib).
